@@ -1,18 +1,23 @@
 package Crypt::OpenSSL::X509;
 
-use warnings;
 use strict;
-
+use vars qw($VERSION @EXPORT_OK);
 use Exporter;
 use base qw(Exporter);
 
-our $VERSION = '1.100';
+$VERSION = '1.800.1';
 
-our @EXPORT_OK = qw(
-  FORMAT_UNDEF FORMAT_ASN1 FORMAT_TEXT FORMAT_PEM
+@EXPORT_OK = qw(
+  FORMAT_UNDEF FORMAT_ASN1 FORMAT_TEXT FORMAT_PEM FORMAT_NETSCAPE
   FORMAT_PKCS12 FORMAT_SMIME FORMAT_ENGINE FORMAT_IISSGC OPENSSL_VERSION_NUMBER
 );
 
+sub Crypt::OpenSSL::X509::bit_length {
+  my $x509 = shift;
+
+  return length($x509->modulus) * 4; # each character is one hex digit = 4 bits
+}
+
 sub Crypt::OpenSSL::X509::has_extension_oid {
   my $x509 = shift;
   my $oid  = shift;
@@ -83,8 +88,14 @@ sub Crypt::OpenSSL::X509::is_selfsigned {
   return $x509->subject eq $x509->issuer;
 }
 
-use XSLoader;
-XSLoader::load 'Crypt::OpenSSL::X509', $VERSION;
+BOOT_XS: {
+  require DynaLoader;
+
+  # DynaLoader calls dl_load_flags as a static method.
+  *dl_load_flags = DynaLoader->can('dl_load_flags');
+
+  do {__PACKAGE__->can('bootstrap') || \&DynaLoader::bootstrap}->(__PACKAGE__, $VERSION);
+}
 
 END {
   __PACKAGE__->__X509_cleanup;
@@ -94,8 +105,6 @@ END {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Crypt::OpenSSL::X509 - Perl extension to OpenSSL's X509 API.
@@ -108,17 +117,16 @@ Crypt::OpenSSL::X509 - Perl extension to OpenSSL's X509 API.
 
   print $x509->pubkey() . "\n";
   print $x509->subject() . "\n";
-  print $x509->hash() . "\n";
-  print $x509->email() . "\n";
   print $x509->issuer() . "\n";
-  print $x509->issuer_hash() . "\n";
+  print $x509->email() . "\n";
+  print $x509->hash() . "\n";
   print $x509->notBefore() . "\n";
   print $x509->notAfter() . "\n";
   print $x509->modulus() . "\n";
   print $x509->exponent() . "\n";
+  print $x509->fingerprint_sha1() . "\n";
   print $x509->fingerprint_md5() . "\n";
-  print $x509->fingerprint_sha256() . "\n";
-  print $x509->as_string() . "\n";
+  print $x509->as_string(Crypt::OpenSSL::X509::FORMAT_TEXT) . "\n";
 
   my $x509 = Crypt::OpenSSL::X509->new_from_string(
     $der_encoded_data, Crypt::OpenSSL::X509::FORMAT_ASN1
@@ -126,9 +134,9 @@ Crypt::OpenSSL::X509 - Perl extension to OpenSSL's X509 API.
 
   # given a time offset of $seconds, will the certificate be valid?
   if ($x509->checkend($seconds)) {
-    # cert is expired at $seconds offset
-  } else {
     # cert is ok at $seconds offset
+  } else {
+    # cert is expired at $seconds offset
   }
 
   my $exts = $x509->extensions_by_oid();
@@ -159,7 +167,7 @@ None by default.
 
 On request:
 
-	FORMAT_UNDEF FORMAT_ASN1 FORMAT_TEXT FORMAT_PEM
+	FORMAT_UNDEF FORMAT_ASN1 FORMAT_TEXT FORMAT_PEM FORMAT_NETSCAPE
 	FORMAT_PKCS12 FORMAT_SMIME FORMAT_ENGINE FORMAT_IISSGC
 
 
@@ -193,20 +201,12 @@ Subject name as a string.
 
 Issuer name as a string.
 
-=item issuer_hash
-
-Issuer name hash as a string.
-
 =item serial
 
 Serial number as a string.
 
 =item hash
 
-Alias for subject_hash
-
-=item subject_hash
-
 Subject name hash as a string.
 
 =item notBefore
@@ -219,7 +219,7 @@ C<notAfter> time as a string.
 
 =item email
 
-Email addresses as string, if multiple addresses found, they are seperated by a space (' ').
+Email address as a string.
 
 =item version
 
@@ -229,14 +229,6 @@ Certificate version as a string.
 
 Signature algorithm name as a string.
 
-=item key_alg_name
-
-Public key algorithm name as a string.
-
-=item curve
-
-Name of the EC curve used in the public key.
-
 =back
 
 =head2 X509 METHODS
@@ -255,11 +247,11 @@ Return Boolean value if subject and issuer name are the same.
 
 =item as_string ( [ FORMAT ] )
 
-Return the certificate as a string in the specified format. C<FORMAT> can be one of C<FORMAT_PEM> (the default) or C<FORMAT_ASN1>.
+Return the certificate as a string in the specified format. C<FORMAT> can be one of C<FORMAT_PEM> (the default), C<FORMAT_ASN1>, or C<FORMAT_NETSCAPE>.
 
 =item modulus ( )
 
-Return the modulus for an RSA public key as a string of hex digits. For DSA and EC return the public key. Other algorithms are not supported.
+Return the modulus for an RSA public key as a string of hex digits. For DSA, return the public key. Other algorithms are not supported.
 
 =item bit_length ( )
 
@@ -269,23 +261,15 @@ Return the length of the modulus as a number of bits.
 
 =item fingerprint_sha1 ( )
 
-=item fingerprint_sha224 ( )
-
-=item fingerprint_sha256 ( )
-
-=item fingerprint_sha384 ( )
-
-=item fingerprint_sha512 ( )
-
 Return the specified message digest for the certificate.
 
 =item checkend( OFFSET )
 
-Given an offset in seconds, will the certificate be expired? Returns True if the certificate will be expired. False otherwise.
+Given an offset in seconds, will the certificate be expired?
 
 =item pubkey ( )
 
-Return the RSA, DSA, or EC public key.
+Return the RSA or DSA public key.
 
 =item num_extensions ( )
 
@@ -297,9 +281,7 @@ Return the Extension specified by the integer C<INDEX>.
 Methods for handling Extension objects are given below.
 
 =item extensions_by_oid ( )
-
 =item extensions_by_name ( )
-
 =item extensions_by_long_name ( )
 
 Return a hash of Extensions indexed by OID or name.
@@ -326,11 +308,9 @@ Methods for handling ObjectID objects are given below.
 
 =item value ( )
 
-Return the value of the extension as an asn1parse(1) style hex dump.
-
-=item as_string ( )
-
-Return a human-readable version of the extension as formatted by X509V3_EXT_print. Note that this will return an empty string for OIDs with unknown ASN.1 encodings.
+Return the value or data of the extension.
+FIXME: the value is returned as a string but may represent
+a complex object.
 
 =back
 
@@ -344,7 +324,7 @@ Return the long name of the object as a string.
 
 =item oid ( )
 
-Return the numeric dot-separated form of the object identifier as a string.
+Return the numeric dot-seperated form of the object identifier as a string.
 
 =back
 
@@ -418,31 +398,16 @@ OpenSSL(1), Crypt::OpenSSL::RSA, Crypt::OpenSSL::Bignum
 
 =head1 AUTHOR
 
-Dan Sully
+Dan Sully, E<lt>daniel@cpan.orgE<gt>
 
 =head1 CONTRIBUTORS
 
-=over
-
-=item * Patrick Cernko, release 1.10.0
-
-=item * Shoichi Kaji, release 1.9.3 and 1.9.8
-
-=item * Neil Bowers, release 1.8.13
-
-=item * kmx, release 1.8.9
-
-=item * Sebastian Andrzej Siewior
-
-=item * David O'Callaghan, E<lt>david.ocallaghan@cs.tcd.ieE<gt>
-
-=item * Daniel Kahn Gillmor E<lt>dkg@fifthhorseman.netE<gt>
-
-=back
+David O'Callaghan, E<lt>david.ocallaghan@cs.tcd.ieE<gt>
+Daniel Kahn Gillmor E<lt>dkg@fifthhorseman.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2021 by Dan Sully
+Copyright 2004-2011 by Dan Sully
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
